@@ -27,16 +27,7 @@ sub stc_scintilla_dll {
 	return $dllname;
 }
 
-sub stc_scintilla_link {
-	my $self     = shift;
-	my $linkname = '-lwx_gtk2';
-	$linkname .= 'u' if Alien::wxWidgets->config->{unicode};
-	$linkname .= 'd' if Alien::wxWidgets->config->{debug};
-	$linkname .= '_scintilla-';
-	my ( $major, $minor, $release ) = $self->stc_version_strings;
-	$linkname .= $major . '.' . $minor;
-	return $linkname;
-}
+sub stc_scintilla_link { $_[0]->stc_scintilla_dll; }
 
 sub stc_build_scintilla_object {
 	my ( $self, $module, $object_name, $includedirs ) = @_;
@@ -47,11 +38,8 @@ sub stc_build_scintilla_object {
 		$self->stc_defines,
 		'-c -fPIC',
 		'-o ' . $object_name,
-		'-O2',
-		'-Wall',
-		$object_name !~ /((Plat|Scintilla)WX|scintilla)\.o/
-		? '-Wno-missing-braces -Wno-char-subscripts'
-		: '',
+		'-O2 ',
+		'-Wall ',
 		'-MT' . $object_name,
 		'-MF' . $object_name . '.d',
 		'-MD -MP',
@@ -62,34 +50,6 @@ sub stc_build_scintilla_object {
 	$self->_run_command( \@cmd );
 }
 
-sub stc_prebuild_check {
-	my $self      = shift;
-	my $ld        = Alien::wxWidgets->linker;
-	my $libstring = $self->stc_extra_scintilla_libs;
-	my $outfile   = 'stc_checkdepends.out';
-	my $command   = qq($ld -fPIC -shared $libstring -o $outfile);
-	if ( system($command) ) {
-		unlink($outfile);
-		print qq(Check for gtk2 development libraries failed.\n);
-		print qq(Perhaps you need to install package libgtk2.0-dev or the equivalent for your system.\n);
-		print qq(You can ofcourse uninstall it later after the installation is complete.\n);
-		print qq(The build cannot continue.\n);
-		exit(1);
-	}
-	unlink($outfile);
-	return 1;
-}
-
-sub stc_extra_scintilla_libs {
-	my $self   = shift;
-	my $extras = '-lgtk-x11-2.0 -lgdk-x11-2.0 -latk-1.0 -lpangoft2-1.0 ';
-	$extras .= '-lgdk_pixbuf-2.0 -lm -lpango-1.0 -lfreetype -lfontconfig -lgobject-2.0 ';
-	$extras .= '-lgmodule-2.0 -lgthread-2.0 -lrt -lglib-2.0 -lpng -lz -ldl -lm ';
-
-	#'-lgio-2.0', # does not apper to be needed and not present on some systems
-	return $extras;
-}
-
 sub stc_link_scintilla_objects {
 	my ( $self, $shared_lib, $objects ) = @_;
 
@@ -100,9 +60,16 @@ sub stc_link_scintilla_objects {
 		' -o ' . $shared_lib,
 		join( ' ', @$objects ),
 		$self->stc_link_paths,
-		$self->stc_extra_scintilla_libs,
+		'-lgtk-x11-2.0 -lgdk-x11-2.0',
+		'-latk-1.0',
+
+		#'-lgio-2.0', # does not apper to be needed and not present on some systems
+		'-lpangoft2-1.0 -lgdk_pixbuf-2.0 -lm -lpango-1.0 -lfreetype -lfontconfig -lgobject-2.0',
+		'-lgmodule-2.0 -lgthread-2.0 -lrt -lglib-2.0 -lpng -lz -ldl -lm',
 		Alien::wxWidgets->libraries(qw(core base)),
-		'-Wl,-soname,' . $self->stc_scintilla_dll,
+		'-Wl,-soname,' . $shared_lib,
+
+
 	);
 
 	$self->_run_command( \@cmd );
@@ -111,9 +78,6 @@ sub stc_link_scintilla_objects {
 sub stc_build_xs {
 	my ($self) = @_;
 
-	# Do not build XS if it is up to date
-	return if $self->up_to_date( 'Scintilla.c', 'Scintilla.o' );
-
 	my $dist_version = $self->dist_version;
 
 	my @cmd = (
@@ -121,7 +85,7 @@ sub stc_build_xs {
 		'-fPIC -c -o Scintilla.o',
 		'-I.',
 		'-I' . $self->stc_get_wx_include_path,
-		'-I' . $Config{archlibexp} . '/CORE',
+		'-I' . $Config{archlib} . '/CORE',
 		Alien::wxWidgets->include_path,
 		Alien::wxWidgets->c_flags,
 		Alien::wxWidgets->defines,
@@ -137,6 +101,8 @@ sub stc_build_xs {
 sub stc_link_xs {
 	my ( $self, $dll ) = @_;
 
+	my $perllib = $self->stc_find_libperl;
+
 	my @cmd = (
 		Alien::wxWidgets->linker,
 		Alien::wxWidgets->link_flags,
@@ -144,14 +110,52 @@ sub stc_link_xs {
 		'-fPIC -L.',
 		'-s -o ' . $dll,
 		'Scintilla.o',
-		'-Lblib/arch/auto/Wx/Scintilla ' . $self->stc_scintilla_link,
+		$perllib,
+		'blib/arch/auto/Wx/Scintilla/' . $self->stc_scintilla_link,
 		Alien::wxWidgets->libraries(qw(core base)),
 		$Config{perllibs},
-		"-Wl,-rpath,'\$ORIGIN'",
+		'-Wl,-rpath,blib/arch/auto/Wx/Scintilla',
+		'-Wl,-rpath,' . File::Spec->catfile( $self->install_destination('arch'), 'auto/Wx/Scintilla' ),
+
 	);
 
 	$self->_run_command( \@cmd );
-
 }
 
+sub stc_find_libperl {
+	my $self = shift;
+
+	# this method has had fairly wide testing in another project
+	my $libperlname = $Config{libperl};
+	my $archlib     = $Config::Config{archlib};
+	my $link        = ( $libperlname =~ /\.a$/ ) ? 'static' : 'shared';
+
+	if ( $link eq 'static' ) {
+		return qq($archlib/CORE/$libperlname);
+	}
+
+	my $testforlibperl = $libperlname;
+	$testforlibperl =~ s/\.a$/\.so/;
+	my $dllpath = qq($archlib/CORE/$testforlibperl);
+	return $dllpath if -f $dllpath;
+	if ( $link eq 'shared' ) {
+
+		# search elsewhere
+		my $returnpath = '';
+		my @libperlpaths = split( /\s+/, $Config::Config{libpth} );
+		for my $libdir (@libperlpaths) {
+			if ( -f qq($libdir/$testforlibperl) ) {
+				$returnpath = (qq($libdir/$libperlname));
+				last;
+			}
+		}
+		return $returnpath;
+	} else {
+		return '';
+	}
+}
+
+
+
+
 1;
