@@ -1,6 +1,5 @@
 package Module::Build::Scintilla::OSX;
 
-use 5.006;
 use strict;
 use warnings;
 use Module::Build::Scintilla;
@@ -36,7 +35,7 @@ sub stc_scintilla_dll {
 	$dllname .= 'd' if Alien::wxWidgets->config->{debug};
 	$dllname .= '_scintilla-';
 	my ( $major, $minor, $release ) = $self->stc_version_strings;
-	$dllname .= $major . '.' . $minor . '.' . $release . '.dylib';
+	$dllname .= $major . '.' . $minor . '.dylib';
 	return $dllname;
 }
 
@@ -59,12 +58,15 @@ sub stc_build_scintilla_object {
 		$self->stc_get_architecture_string,
 		$self->stc_ccflags,
 		$self->stc_defines,
+
+		#'-fPIC',
 		'-o ' . $object_name,
-		'-O2',
-		'-Wall',
-		$object_name !~ /((Plat|Scintilla)WX|scintilla)\.o/
-		? '-Wno-missing-braces -Wno-char-subscripts'
-		: '',
+		'-O2 ',
+		'-Wall ',
+
+		#'-MT' . $object_name,
+		#'-MF' . $object_name . '.d',
+		#'-MD -MP',
 		join( ' ', @$includedirs ),
 		$module,
 	);
@@ -80,6 +82,8 @@ sub stc_link_scintilla_objects {
 		$self->stc_get_architecture_string,
 		$self->stc_ldflags,
 		'-headerpad_max_install_names',
+
+		#'-shared -fPIC',
 		'-shared',
 		' -o ' . $shared_lib,
 		join( ' ', @$objects ),
@@ -92,9 +96,6 @@ sub stc_link_scintilla_objects {
 sub stc_build_xs {
 	my ($self) = @_;
 
-	# Do not build XS if it is up to date
-	return if $self->up_to_date( 'Scintilla.c', 'Scintilla.o' );
-
 	my $dist_version = $self->dist_version;
 
 	# we must remove any nostdinc params
@@ -124,10 +125,13 @@ sub stc_build_xs {
 sub stc_link_xs {
 	my ( $self, $dll ) = @_;
 
+	my $perllib = $self->stc_find_libperl;
+
 	# we must remove any nostdinc params
 	my $ldflags = $Config{lddlflags};
 	$ldflags =~ s/-nostdinc //g;
 
+
 	my @cmd = (
 		Alien::wxWidgets->linker,
 		$self->stc_get_architecture_string,
@@ -137,6 +141,7 @@ sub stc_link_xs {
 		'-L.',
 		'-s -o ' . $dll,
 		'Scintilla.o',
+		$perllib,
 		'blib/arch/auto/Wx/Scintilla/' . $self->stc_scintilla_link,
 		Alien::wxWidgets->libraries(qw(core base)),
 		$Config{perllibs},
@@ -146,6 +151,34 @@ sub stc_link_xs {
 
 }
 
+sub stc_find_libperl {
+	my $self        = shift;
+	my $libperlname = $Config{libperl};
+	my $archlib     = $Config::Config{archlib};
+	my $link        = ( $libperlname =~ /\.a$/ ) ? 'static' : 'shared';
+
+	if ( $link eq 'static' ) {
+		return qq($archlib/CORE/$libperlname);
+	} else {
+		my $returnpath     = '';
+		my $testforlibperl = $libperlname;
+		$testforlibperl =~ s/\.a$/\.dylib/;
+		my $dllpath = qq($archlib/CORE/$testforlibperl);
+		return $dllpath if -f $dllpath;
+
+		# search elsewhere
+
+		my @libperlpaths = split( /\s+/, $Config::Config{libpth} );
+		for my $libdir (@libperlpaths) {
+			if ( -f qq($libdir/$testforlibperl) ) {
+				$returnpath = (qq($libdir/$libperlname));
+				last;
+			}
+		}
+		return $returnpath;
+	}
+}
+
 # We need our own run command to strip out none buildable architectures
 sub _run_command {
 	my $self = shift;
